@@ -146,7 +146,17 @@ class BasicElement():
         try:
         # qf = ' and '.join([ f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)' if isinstance(att['val'], str) else f'm.`{att["dim"]}` == {att["val"]}' for att in query])
             # qf = ' and '.join([ f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)' if isinstance(att['val'], str) else f'm.`{att["dim"]}` {att["op"]} {att["val"]}' for att in query])
-            qf = ' and '.join([ f'm.`{att["dim"]}` {att["op"]} "{att["val"]}"' if isinstance(att['val'], str) else f'm.`{att["dim"]}` {att["op"]} {att["val"]}' for att in query])
+            filters_list = []
+            for att in query:
+                if isinstance(att['val'], str):
+                    if att["op"] == '=~':
+                        filters_list.append(f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)')
+                    else:
+                        filters_list.append(f'm.`{att["dim"]}` {att["op"]} "{att["val"]}"')
+                else:
+                    filters_list.append(f'm.`{att["dim"]}` {att["op"]} {att["val"]}')
+            qf = ' and '.join(filters_list)
+            # qf = ' and '.join([ f'm.`{att["dim"]}` {att["op"]} "{att["val"]}"' if isinstance(att['val'], str) else f'm.`{att["dim"]}` {att["op"]} {att["val"]}' for att in query])
             if limit != None:
                 qf = qf + ' limit ' + str(limit)
             query = 'for m in '+ self.get_collection() +'\
